<?php

namespace Drupal\calculation_fields;

use Drupal\Core\Render\Element;

/**
 *
 */
trait CalculationFieldsTrait {

  /**
   * Extract info from the expression field.
   *
   * @param string $field
   *   Field expression info.
   *
   * @return array
   *   Array with field name and default value if defined.
   */
  public static function getExpInfo($field) {
    $defaultValue = NULL;
    $info = explode('|', $field);
    if (count($info) === 2) {
      $defaultValue = $info[1];
    }
    return [
      $info[0],
      $defaultValue
    ];
  }

  /**
   * Get reference to first element by name.
   *
   * @param array $elements
   *   An associative array of elements.
   * @param string $name
   *   The element's name.
   *
   * @return array|null
   *   Reference to found element.
   */
  public static function &getElement(array &$elements, $name) {
    foreach (Element::children($elements) as $element_name) {
      if ($element_name === $name) {
        return $elements[$element_name];
      }
      elseif (is_array($elements[$element_name])) {
        $child_elements = &$elements[$element_name];
        if ($element = &static::getElement($child_elements, $name)) {
          return $element;
        }
      }
    }
    $element = NULL;
    return $element;
  }

}
